@@ -5,14 +5,17 @@ import inspect
 import sre_compile
 import sys
 import types
-from typing import Any, List, Pattern, TypeVar, Literal, Union, get_args, get_origin
+from typing import Any, List, Pattern, TypeVar, Literal, Union, get_args, get_origin, TYPE_CHECKING
 
 from typing_extensions import Annotated
 
 Empty = inspect.Signature.empty
-GenericAlias = type(List[int])
+if TYPE_CHECKING:
+    from types import GenericAlias  # noqa
+else:
+    GenericAlias: type = type(List[int])
 TPattern: type[Pattern] = type(sre_compile.compile("", 0))
-AnnotatedType = type(Annotated[int, lambda x: x > 0])
+AnnotatedType: type = type(Annotated[int, lambda x: x > 0])
 Unions = (Union, types.UnionType) if sys.version_info >= (3, 10) else (Union,)  # pragma: no cover
 
 
@@ -39,9 +42,9 @@ def generic_isinstance(obj: Any, par: type | Any | tuple[type, ...]) -> bool:
             return isinstance(obj, par)
         if get_origin(par) is Literal:
             return obj in get_args(par)
-        if get_origin(par) in Unions:
+        if get_origin(par) in Unions:  # pragma: no cover
             return any(generic_isinstance(obj, p) for p in get_args(par))
-        if isinstance(par, TypeVar):
+        if isinstance(par, TypeVar):  # pragma: no cover
             if par.__constraints__:
                 return any(generic_isinstance(obj, p) for p in par.__constraints__)
             return generic_isinstance(obj, par.__bound__) if par.__bound__ else True
@@ -50,6 +53,3 @@ def generic_isinstance(obj: Any, par: type | Any | tuple[type, ...]) -> bool:
         if isinstance(obj, get_origin(par)):  # type: ignore
             return True
     return False
-
-
-__all__ = ["GenericAlias", "TPattern", "generic_isinstance", "Empty", "AllParam"]
